Payload class

Constructors

Payload({required String mccCode, required String billId, required int amount, required String expired})

Properties

amount int
getter/setter pair
billId String
getter/setter pair
expired String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mccCode String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited